# Generated by Django 2.2.24 on 2021-11-02 12:00

import django.db.models.deletion
import wagtail.core.models
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("wagtailcore", "0041_group_collection_permissions_verbose_name_plural"),
        ("wagtail_embed_videos", "0002_auto_20180822_0945"),
    ]

    operations = [
        migrations.AddField(
            model_name="embedvideo",
            name="collection",
            field=models.ForeignKey(
                default=wagtail.core.models.get_root_collection_id,
                on_delete=django.db.models.deletion.CASCADE,
                related_name="+",
                to="wagtailcore.Collection",
                verbose_name="collection",
            ),
        ),
    ]
